You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by ke...@apache.org on 2006/10/18 14:25:20 UTC

svn commit: r465232 [1/2] - in /incubator/tuscany/java: sdo/ sdo/distribution/ sdo/distribution/src/ sdo/impl/ sdo/impl/src/main/java/org/apache/tuscany/sdo/ sdo/impl/src/test/resources/ sdo/sample/ sdo/sample/distribution/ sdo/sample/src/main/java/org...

Author: kelvingoodson
Date: Wed Oct 18 05:25:18 2006
New Revision: 465232

URL: http://svn.apache.org/viewvc?view=rev&rev=465232
Log:
merge back differences from the M2 tag to trunk, (excluding SDO 2.1 spec enhancements already in trunk, SNAPSHOT versioning and any enhancements made to trunk while branched/tagged)

Added:
    incubator/tuscany/java/sdo/LICENSE.txt
    incubator/tuscany/java/sdo/NOTICE.txt
    incubator/tuscany/java/sdo/distribution/readme.html
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/overview.html
    incubator/tuscany/java/sdo/sample/LICENSE.txt
    incubator/tuscany/java/sdo/sample/NOTICE.txt
    incubator/tuscany/java/sdo/sample/README.txt
    incubator/tuscany/java/sdo/sample/STATUS.txt
    incubator/tuscany/java/sdo/sdo.xml
    incubator/tuscany/java/spec/sdo-api/STATUS.txt
    incubator/tuscany/java/spec/sdo-api/src/main/java/commonj/sdo/overview.html
Removed:
    incubator/tuscany/java/sdo/distribution/CHANGES.txt
    incubator/tuscany/java/sdo/distribution/LICENSE.txt
    incubator/tuscany/java/sdo/distribution/NOTICE.txt
    incubator/tuscany/java/sdo/distribution/STATUS
    incubator/tuscany/java/sdo/distribution/pom.xml
    incubator/tuscany/java/sdo/distribution/src/
    incubator/tuscany/java/sdo/sample/distribution/
    incubator/tuscany/java/spec/sdo-api/STATUS
Modified:
    incubator/tuscany/java/sdo/BUILDING.txt
    incubator/tuscany/java/sdo/distribution/RELEASE_NOTES.txt
    incubator/tuscany/java/sdo/impl/pom.xml
    incubator/tuscany/java/sdo/impl/src/test/resources/XMLDocumentNoNamespaceSchemaLocation.xsd
    incubator/tuscany/java/sdo/impl/src/test/resources/XMLDocumentSchemaLocation.xsd
    incubator/tuscany/java/sdo/impl/src/test/resources/api_test.xsd
    incubator/tuscany/java/sdo/impl/src/test/resources/bank.xsd
    incubator/tuscany/java/sdo/impl/src/test/resources/datatype.xsd
    incubator/tuscany/java/sdo/impl/src/test/resources/foo-ext.xsd
    incubator/tuscany/java/sdo/impl/src/test/resources/foo.xsd
    incubator/tuscany/java/sdo/impl/src/test/resources/mixed.xsd
    incubator/tuscany/java/sdo/impl/src/test/resources/names.xsd
    incubator/tuscany/java/sdo/impl/src/test/resources/open.xsd
    incubator/tuscany/java/sdo/impl/src/test/resources/sdoannotations.xsd
    incubator/tuscany/java/sdo/impl/src/test/resources/sdotypes.xsd
    incubator/tuscany/java/sdo/impl/src/test/resources/simple.xsd
    incubator/tuscany/java/sdo/pom.xml
    incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/ExecuteSamples.java
    incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/otherSources/CreatePurchaseOrder.java
    incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/otherSources/ReadPurchaseOrder.java
    incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/otherSources/package.html
    incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/overview.html
    incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/package.html
    incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specCodeSnippets/AccessDataObjectUsingValidXPath.java
    incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specCodeSnippets/UsingXPath.java
    incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specCodeSnippets/package.html
    incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/specExampleSection/package.html
    incubator/tuscany/java/sdo/tools/pom.xml
    incubator/tuscany/java/sdo/tools/readme.htm
    incubator/tuscany/java/sdo/tools/src/test/resources/enum.xsd
    incubator/tuscany/java/sdo/tools/src/test/resources/repeatingChoice.xsd
    incubator/tuscany/java/sdo/tools/src/test/resources/sequences.xsd
    incubator/tuscany/java/sdo/tools/src/test/resources/simple.xsd
    incubator/tuscany/java/spec/sdo-api/pom.xml

Modified: incubator/tuscany/java/sdo/BUILDING.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/BUILDING.txt?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/BUILDING.txt (original)
+++ incubator/tuscany/java/sdo/BUILDING.txt Wed Oct 18 05:25:18 2006
@@ -1,5 +1,14 @@
-Building the SDO Java Implementation Project from the source distribution 
-=========================================================================
+Building SDO Releases
+=====================
+The SDO specification source distribution and the SDO implementation source distribution
+together with a computer with a live internet connection, maven 2.0.4 installed and java 1.4.2
+or above installed are all you need to build
+1) the SDO binary distribution
+2) the SDO samples source distribution (note that the source distribution is a derivative of
+the binary distribution, since it ships with javadoc,  which is generated by the binary distribution)
+
+Building the SDO Java Implementation Project Binary Release from the source distribution 
+========================================================================================
 (note,  these instructions are for building the SDO binary release from
 source, not for establishing a development environment.  If you wish to
 participate in sdo development, follow the instructions at 
@@ -15,12 +24,25 @@
    build step, then you will need to delete the file
    sdo/tools/src/main/java/org/apache/tuscany/sdo/generate/Interface2JavaGenerator.java before proceding
 4) Change to the top level directory of the Tuscany SDO Java Implementation project (sdo) of this source distribution.
-5) Execute: mvn
-   This will first place build artefacts in your local maven repository that your SDO programs can depend upon. It
-   will then build the Tuscany SDO for Java binary distribution artefacts in the sdo/distribution/target
-   directory and the self contained Tuscany SDO for Java samples distribution in the directory sdo/sample/target.
+6) Execute: mvn
+   This will install the sdo implementation jar in you local repository
+5) Execute: mvn package javadoc:javadoc assembly:assembly
+   This will build the Tuscany SDO for Java binary distribution artefacts in the sdo/distribution/target
+   directory.
 
 Note: Depending on the load being experienced by remote Maven 2.0 repositories you may have to execute mvn several
     times until required dependencies are all located in your local maven repository.  After you have completed a
     full successful build you can use "mvn -o" which is much faster.
 
+6) To run the sample programs, change directory to the "sample" directory, and run the command "mvn".  Then look in the sample/target/site/apidocs/index.html file for javadoc that describes how to run the samples.
+
+
+Building the SDO Samples Source distribution
+============================================
+
+To build the SDO Samples source distribution
+1) copy the sdo/sample directory from the SDO implementation source distribution to a temporary folder
+2) Build the SDO binary distribution as instructed above
+3) From the top level directory of your SDO implementation build tree change directory to the sample directory and execute the command mvn javadoc:javadoc to create javadoc for the samples in the target/site directory
+4) copy the site folder to the temporary directory created for step 1
+4) create .zip and .tar.gz archives of the sample source and javadoc
\ No newline at end of file

Added: incubator/tuscany/java/sdo/LICENSE.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/LICENSE.txt?view=auto&rev=465232
==============================================================================
--- incubator/tuscany/java/sdo/LICENSE.txt (added)
+++ incubator/tuscany/java/sdo/LICENSE.txt Wed Oct 18 05:25:18 2006
@@ -0,0 +1,238 @@
+
+                                 Apache License
+                           Version 2.0, January 2004
+                        http://www.apache.org/licenses/
+
+   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION
+
+   1. Definitions.
+
+      "License" shall mean the terms and conditions for use, reproduction,
+      and distribution as defined by Sections 1 through 9 of this document.
+
+      "Licensor" shall mean the copyright owner or entity authorized by
+      the copyright owner that is granting the License.
+
+      "Legal Entity" shall mean the union of the acting entity and all
+      other entities that control, are controlled by, or are under common
+      control with that entity. For the purposes of this definition,
+      "control" means (i) the power, direct or indirect, to cause the
+      direction or management of such entity, whether by contract or
+      otherwise, or (ii) ownership of fifty percent (50%) or more of the
+      outstanding shares, or (iii) beneficial ownership of such entity.
+
+      "You" (or "Your") shall mean an individual or Legal Entity
+      exercising permissions granted by this License.
+
+      "Source" form shall mean the preferred form for making modifications,
+      including but not limited to software source code, documentation
+      source, and configuration files.
+
+      "Object" form shall mean any form resulting from mechanical
+      transformation or translation of a Source form, including but
+      not limited to compiled object code, generated documentation,
+      and conversions to other media types.
+
+      "Work" shall mean the work of authorship, whether in Source or
+      Object form, made available under the License, as indicated by a
+      copyright notice that is included in or attached to the work
+      (an example is provided in the Appendix below).
+
+      "Derivative Works" shall mean any work, whether in Source or Object
+      form, that is based on (or derived from) the Work and for which the
+      editorial revisions, annotations, elaborations, or other modifications
+      represent, as a whole, an original work of authorship. For the purposes
+      of this License, Derivative Works shall not include works that remain
+      separable from, or merely link (or bind by name) to the interfaces of,
+      the Work and Derivative Works thereof.
+
+      "Contribution" shall mean any work of authorship, including
+      the original version of the Work and any modifications or additions
+      to that Work or Derivative Works thereof, that is intentionally
+      submitted to Licensor for inclusion in the Work by the copyright owner
+      or by an individual or Legal Entity authorized to submit on behalf of
+      the copyright owner. For the purposes of this definition, "submitted"
+      means any form of electronic, verbal, or written communication sent
+      to the Licensor or its representatives, including but not limited to
+      communication on electronic mailing lists, source code control systems,
+      and issue tracking systems that are managed by, or on behalf of, the
+      Licensor for the purpose of discussing and improving the Work, but
+      excluding communication that is conspicuously marked or otherwise
+      designated in writing by the copyright owner as "Not a Contribution."
+
+      "Contributor" shall mean Licensor and any individual or Legal Entity
+      on behalf of whom a Contribution has been received by Licensor and
+      subsequently incorporated within the Work.
+
+   2. Grant of Copyright License. Subject to the terms and conditions of
+      this License, each Contributor hereby grants to You a perpetual,
+      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
+      copyright license to reproduce, prepare Derivative Works of,
+      publicly display, publicly perform, sublicense, and distribute the
+      Work and such Derivative Works in Source or Object form.
+
+   3. Grant of Patent License. Subject to the terms and conditions of
+      this License, each Contributor hereby grants to You a perpetual,
+      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
+      (except as stated in this section) patent license to make, have made,
+      use, offer to sell, sell, import, and otherwise transfer the Work,
+      where such license applies only to those patent claims licensable
+      by such Contributor that are necessarily infringed by their
+      Contribution(s) alone or by combination of their Contribution(s)
+      with the Work to which such Contribution(s) was submitted. If You
+      institute patent litigation against any entity (including a
+      cross-claim or counterclaim in a lawsuit) alleging that the Work
+      or a Contribution incorporated within the Work constitutes direct
+      or contributory patent infringement, then any patent licenses
+      granted to You under this License for that Work shall terminate
+      as of the date such litigation is filed.
+
+   4. Redistribution. You may reproduce and distribute copies of the
+      Work or Derivative Works thereof in any medium, with or without
+      modifications, and in Source or Object form, provided that You
+      meet the following conditions:
+
+      (a) You must give any other recipients of the Work or
+          Derivative Works a copy of this License; and
+
+      (b) You must cause any modified files to carry prominent notices
+          stating that You changed the files; and
+
+      (c) You must retain, in the Source form of any Derivative Works
+          that You distribute, all copyright, patent, trademark, and
+          attribution notices from the Source form of the Work,
+          excluding those notices that do not pertain to any part of
+          the Derivative Works; and
+
+      (d) If the Work includes a "NOTICE" text file as part of its
+          distribution, then any Derivative Works that You distribute must
+          include a readable copy of the attribution notices contained
+          within such NOTICE file, excluding those notices that do not
+          pertain to any part of the Derivative Works, in at least one
+          of the following places: within a NOTICE text file distributed
+          as part of the Derivative Works; within the Source form or
+          documentation, if provided along with the Derivative Works; or,
+          within a display generated by the Derivative Works, if and
+          wherever such third-party notices normally appear. The contents
+          of the NOTICE file are for informational purposes only and
+          do not modify the License. You may add Your own attribution
+          notices within Derivative Works that You distribute, alongside
+          or as an addendum to the NOTICE text from the Work, provided
+          that such additional attribution notices cannot be construed
+          as modifying the License.
+
+      You may add Your own copyright statement to Your modifications and
+      may provide additional or different license terms and conditions
+      for use, reproduction, or distribution of Your modifications, or
+      for any such Derivative Works as a whole, provided Your use,
+      reproduction, and distribution of the Work otherwise complies with
+      the conditions stated in this License.
+
+   5. Submission of Contributions. Unless You explicitly state otherwise,
+      any Contribution intentionally submitted for inclusion in the Work
+      by You to the Licensor shall be under the terms and conditions of
+      this License, without any additional terms or conditions.
+      Notwithstanding the above, nothing herein shall supersede or modify
+      the terms of any separate license agreement you may have executed
+      with Licensor regarding such Contributions.
+
+   6. Trademarks. This License does not grant permission to use the trade
+      names, trademarks, service marks, or product names of the Licensor,
+      except as required for reasonable and customary use in describing the
+      origin of the Work and reproducing the content of the NOTICE file.
+
+   7. Disclaimer of Warranty. Unless required by applicable law or
+      agreed to in writing, Licensor provides the Work (and each
+      Contributor provides its Contributions) on an "AS IS" BASIS,
+      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
+      implied, including, without limitation, any warranties or conditions
+      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
+      PARTICULAR PURPOSE. You are solely responsible for determining the
+      appropriateness of using or redistributing the Work and assume any
+      risks associated with Your exercise of permissions under this License.
+
+   8. Limitation of Liability. In no event and under no legal theory,
+      whether in tort (including negligence), contract, or otherwise,
+      unless required by applicable law (such as deliberate and grossly
+      negligent acts) or agreed to in writing, shall any Contributor be
+      liable to You for damages, including any direct, indirect, special,
+      incidental, or consequential damages of any character arising as a
+      result of this License or out of the use or inability to use the
+      Work (including but not limited to damages for loss of goodwill,
+      work stoppage, computer failure or malfunction, or any and all
+      other commercial damages or losses), even if such Contributor
+      has been advised of the possibility of such damages.
+
+   9. Accepting Warranty or Additional Liability. While redistributing
+      the Work or Derivative Works thereof, You may choose to offer,
+      and charge a fee for, acceptance of support, warranty, indemnity,
+      or other liability obligations and/or rights consistent with this
+      License. However, in accepting such obligations, You may act only
+      on Your own behalf and on Your sole responsibility, not on behalf
+      of any other Contributor, and only if You agree to indemnify,
+      defend, and hold each Contributor harmless for any liability
+      incurred by, or claims asserted against, such Contributor by reason
+      of your accepting any such warranty or additional liability.
+
+   END OF TERMS AND CONDITIONS
+
+   APPENDIX: How to apply the Apache License to your work.
+
+      To apply the Apache License to your work, attach the following
+      boilerplate notice, with the fields enclosed by brackets "[]"
+      replaced with your own identifying information. (Don't include
+      the brackets!)  The text should be enclosed in the appropriate
+      comment syntax for the file format. We also recommend that a
+      file or class name and description of purpose be included on the
+      same "printed page" as the copyright notice for easier
+      identification within third-party archives.
+
+   Copyright [yyyy] [name of copyright owner]
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+
+===============================================================================================================
+
+
+License for the Service Data Objects JavaDoc and Interface Definition files.
+
+Permission to copy, make derivative works of, and distribute the Service Data Objects 
+JavaDoc and Interface Definition Files files in any medium without fee or royalty as part 
+of a compliant implementation of the Service Data Objects Specification is hereby granted.  
+The Service Data Objects Specification may be found at any of the following locations:
+
+http://dev2dev.bea.com/technologies/commonj/index.jsp
+http://www.ibm.com/developerworks/library/specification/ws-sdo/
+http://oracle.com/technology/webservices/sca
+https://www.sdn.sap.com/
+http://www.xcalia/xdn/specs/sdo
+
+THE SERVICE DATA OBJECTS SPECIFICATION AND THE JAVADOC AND INTERFACE DEFINITION FILES 
+ARE PROVIDED "AS IS," AND THE AUTHORS MAKE NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED, REGARDING THIS 
+SPECIFICATION OR THE JAVADOC AND INTERFACE DEFINITION FILES AND THE IMPLEMENTATION OF THEIR CONTENTS, 
+INCLUDING, BUT NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, 
+NON-INFRINGEMENT OR TITLE.  THE AUTHORS WILL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, 
+INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF OR RELATING TO ANY USE OR DISTRIBUTION OF THE 
+SERVICE DATA OBJECTS SPECIFICATION OR THE JAVADOC OR INTERFACE DEFINTION FILES.
+
+The name and trademarks of the Authors may NOT be used in any manner, including advertising or 
+publicity pertaining to the Service Component Architecture Specification or its contents without specific, 
+written prior permission. Title to copyright in the Service Data Objects Specification and the 
+JavaDoc and Interface Definition Files will at all times remain with the Authors.
+
+No other rights are granted by implication, estoppel or otherwise.
+
+
+
+
+

Added: incubator/tuscany/java/sdo/NOTICE.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/NOTICE.txt?view=auto&rev=465232
==============================================================================
--- incubator/tuscany/java/sdo/NOTICE.txt (added)
+++ incubator/tuscany/java/sdo/NOTICE.txt Wed Oct 18 05:25:18 2006
@@ -0,0 +1,33 @@
+Apache Tuscany SDO for Java
+Copyright 2006 The Apache Software Foundation
+
+This product includes software developed at
+The Apache Software Foundation (http://www.apache.org/).
+
+Apache Tuscany is an effort undergoing incubation at The Apache Software Foundation (ASF),
+sponsored by the Apache Web Services PMC. Incubation is required of all newly accepted
+projects until a further review indicates that the infrastructure, communications,
+and decision making process have stabilized in a manner consistent with other successful
+ASF projects. While incubation status is not necessarily a reflection of the completeness
+or stability of the code, it does indicate that the project has yet to be fully endorsed
+by the ASF.
+
+Unless otherwise indicated, all distribution made available by the Apache Software Foundation
+is provided to you under the terms and conditions of the Apache License Version 2.0 ("AL").
+A copy of the AL is provided with this distribution as the LICENSE.txt file present in the
+root directory, and is also available at http://www.apache.org/licenses/.
+
+The terms and conditions governing the distribution may refer to the AL or other license
+agreements, notices or terms and conditions. Some of these other license agreements may
+include (but are not limited to):
+
+  . Eclipse Public License Version 1.0 (available at http://www.eclipse.org/legal/epl-v10.html)
+  . Common Public License Version 1.0 (available at http://www.eclipse.org/legal/cpl-v10.html)
+
+It is your obligation to read and accept all such terms and conditions prior to use of the
+distribution. If term or condition is provided, please contact the Apache Software Foundation
+to determine what terms and conditions govern that particular distribution.
+
+This product also includes software developed by the Open Service Oriented Architecture organisation
+(http://osoa.org). The license for this software may be found in the LICENSE.txt file contained in this
+distribution.

Modified: incubator/tuscany/java/sdo/distribution/RELEASE_NOTES.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/distribution/RELEASE_NOTES.txt?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/distribution/RELEASE_NOTES.txt (original)
+++ incubator/tuscany/java/sdo/distribution/RELEASE_NOTES.txt Wed Oct 18 05:25:18 2006
@@ -85,4 +85,43 @@
 
   7. open content creation API (SDO 2.1 enhancement early implementation - see draft 2.1 spec)
     * TypeHelper.createOpenContentProperty()
-    * TypeHelper.getOpenContentProperty()
\ No newline at end of file
+    * TypeHelper.getOpenContentProperty()
+
+  8. sample programs
+    * There are currently three groups of samples
+     8.1. Simple code snippets located throughout the specifiction with comparative methods for acheiving the same results
+         # Create DataObject from XML String
+         # Create DataObject from XSD and XML files
+         # Access DataObject Properties by name
+         # Dynamic "Customer" Type sample
+         # Print Properties of DataObject
+         # Using XPath
+         # Obtaining DataGraph from XML
+     8.2. Full examples located within Examples section of specification
+         # Access DataObjects using XPath
+         # Accessing DataObjects via Property index
+         # Accessing the contents of a Sequence
+         # Creating DataObject trees from XMLDocuments
+         # Creating XML from DataObjects
+         # Serializing desearializing a DataObject
+         # Using Type and Property with DataObjects
+     8.3. Other sample sources such as white papers and online articles
+         # Create PurchaseOrder
+         # Read PurchaseOrder
+         # PurchaseOrder command line
+
+  9. bug fixes
+    * DataObject string accessors were not working for XPath segements with @ prefix, e.g. "@property" (TUSCANY-425)
+    * string accessors fixed to throw IndexOutOfBounds exception for "property[0]" since index starts with 1 (TUSCANY-475)
+    * fixed Date-Type properties (including Day, Date, DateTime, Duration, etc.) that were not working/roundtripping properly (TUSCANY-579/582)
+    * dynamically-created global (open content) properties were not serializing properly (TUSCANY-530/531)
+    * properties created from XSD attributes now appear, in the Type, in the same order as the attributes in the XSD complexType
+    * fixed test harness to allow comments in XML test files (TUSCANY-427)
+    * loading XSDs with nillable elements, of built-in types, caused NPE (TUSCANY-676)
+    * fixed NPE when loading XSD without targetNamespace (TUSCANY-645)
+    * made Type.getProperty(String) implementaion thread safe (TUSCANY-682)
+    * support base64Binary and hexBinary XSD types correctly (TUSCANY-685)
+    * fixed generation of invalid prefixes in XML serialization (TUSCANY-711)
+    * sometimes SDOXMLResourceImpl (instead of XSDResourceImp) was incorrectly used when loading .xsd files (TUSCANY-714)
+    * roundtripping an xsd:anyType via XML using XMLStreamHelper gave wrong kind of DataObject (TUSCANY-755)
+    * cardinality of global elements should be adaptive according to usage context (TUSCANY-115)

Added: incubator/tuscany/java/sdo/distribution/readme.html
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/distribution/readme.html?view=auto&rev=465232
==============================================================================
--- incubator/tuscany/java/sdo/distribution/readme.html (added)
+++ incubator/tuscany/java/sdo/distribution/readme.html Wed Oct 18 05:25:18 2006
@@ -0,0 +1,45 @@
+<HTML>
+<head>
+<title>
+Tuscany SDO for Java M2 Binary Distribution
+</title>
+</head>
+<body>
+<H1>Tuscany SDO for Java M2 Binary Distribution Readme File</h1>
+<h2>Legal Notices</h2>
+<p>
+See the <a href="LICENSE.txt">LICENSE.txt</a> and <a href="NOTICE.txt">NOTICE.txt</a> files for legal information concerning this distribution. 
+</p>
+<h2>Release Information</h2>
+<p>
+See the <a href="RELEASE_NOTES.txt">RELEASE_NOTES.txt</a> file for a summary of what's new with this release,  or the <a href="CHANGES.txt">CHANGES.txt</a> file for a detailed list of the changes since the M1 release.
+</p>
+<h2>Documentation</h2>
+<p>
+For general documentation about the Tuscany project and the SDO for Java, see the <a href="http://incubator.apache.org/tuscany">Tuscany</a> website.
+</p>
+<p>
+This distribution contains javadoc for the <a href="javadoc/api/index.html">SDO 2.0.1 API</a>.
+It also contains Javadoc for the <a href="javadoc/impl/index.html">implementation code</a>.
+Although this is not of general use to the SDO user, there are some classes in the implementation code which are of interest
+to the user of SDO, these include
+<ul>
+
+    <li>org.apache.tuscany.sdo.util.SDOUtil</li>
+    <li>org.apache.tuscany.sdo.generate.XSD2JavaGenerator</li>
+    <li>org.apache.tuscany.sdo.generate.Interface2JavaGenerator</li>
+</ul>
+</p>
+<h2>Samples</h2>
+<p>
+Sample source code is available to <a href="http://incubator.apache.org/tuscany/downloads.html">download</a> as a separate distribution to accompany this binary distribution. 
+Download and unpack a suitable archive and follow the instructions in the archive to build and run the samples.
+</p>
+<p>
+</p>
+<p>
+</p>
+</body>
+</HTML>
+
+

Modified: incubator/tuscany/java/sdo/impl/pom.xml
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/pom.xml?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/impl/pom.xml (original)
+++ incubator/tuscany/java/sdo/impl/pom.xml Wed Oct 18 05:25:18 2006
@@ -107,6 +107,24 @@
                     </archive>
                 </configuration>
             </plugin>
+            <plugin>
+                <groupId>org.apache.maven.plugins</groupId>
+                <artifactId>maven-javadoc-plugin</artifactId>
+                <configuration>
+                    <overview>${basedir}/src/main/java/org/apache/tuscany/sdo/overview.html</overview> 
+                    <version>2.0</version>
+                </configuration>
+                <!-- <executions>
+                    <execution>
+                        <id>package</id>
+                        <phase>package</phase>
+                        <goals>
+                            <goal>jar</goal>
+                        </goals>
+                    </execution>
+                </executions> -->
+            </plugin>
+
         </plugins>
     </build>
 </project>

Added: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/overview.html
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/overview.html?view=auto&rev=465232
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/overview.html (added)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/overview.html Wed Oct 18 05:25:18 2006
@@ -0,0 +1,7 @@
+<HTML>
+<HEAD>
+<TITLE>Foo</TITLE>
+</HEAD>
+<BODY>
+stuff
+</BODY>
\ No newline at end of file

Modified: incubator/tuscany/java/sdo/impl/src/test/resources/XMLDocumentNoNamespaceSchemaLocation.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/test/resources/XMLDocumentNoNamespaceSchemaLocation.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/test/resources/XMLDocumentNoNamespaceSchemaLocation.xsd (original)
+++ incubator/tuscany/java/sdo/impl/src/test/resources/XMLDocumentNoNamespaceSchemaLocation.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
 <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema">
 

Modified: incubator/tuscany/java/sdo/impl/src/test/resources/XMLDocumentSchemaLocation.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/test/resources/XMLDocumentSchemaLocation.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/test/resources/XMLDocumentSchemaLocation.xsd (original)
+++ incubator/tuscany/java/sdo/impl/src/test/resources/XMLDocumentSchemaLocation.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
 <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema"
   targetNamespace="http://www.example.com/xmlDocumentSchemaLocation"

Modified: incubator/tuscany/java/sdo/impl/src/test/resources/api_test.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/test/resources/api_test.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/test/resources/api_test.xsd (original)
+++ incubator/tuscany/java/sdo/impl/src/test/resources/api_test.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
 <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:sdo="commonj.sdo" xmlns:simple="http://www.example.com/api_test" targetNamespace="http://www.example.com/api_test"> 
     <xsd:import namespace="commonj.sdo" schemaLocation="sdoModel.xsd"/>

Modified: incubator/tuscany/java/sdo/impl/src/test/resources/bank.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/test/resources/bank.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/test/resources/bank.xsd (original)
+++ incubator/tuscany/java/sdo/impl/src/test/resources/bank.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
 <xsd:schema targetNamespace="http://www.example.com/bank" 
                  xmlns:bank="http://www.example.com/bank" 

Modified: incubator/tuscany/java/sdo/impl/src/test/resources/datatype.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/test/resources/datatype.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/test/resources/datatype.xsd (original)
+++ incubator/tuscany/java/sdo/impl/src/test/resources/datatype.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
 <xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:datatype="http://www.example.com/datatype" xmlns:sdoJava="commonj.sdo/java" targetNamespace="http://www.example.com/datatype"> 
 

Modified: incubator/tuscany/java/sdo/impl/src/test/resources/foo-ext.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/test/resources/foo-ext.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/test/resources/foo-ext.xsd (original)
+++ incubator/tuscany/java/sdo/impl/src/test/resources/foo-ext.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
 -->
 <schema xmlns="http://www.w3.org/2001/XMLSchema"
 	targetNamespace="http://bar"

Modified: incubator/tuscany/java/sdo/impl/src/test/resources/foo.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/test/resources/foo.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/test/resources/foo.xsd (original)
+++ incubator/tuscany/java/sdo/impl/src/test/resources/foo.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
 <schema xmlns="http://www.w3.org/2001/XMLSchema" 
 		targetNamespace="http://foo" 

Modified: incubator/tuscany/java/sdo/impl/src/test/resources/mixed.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/test/resources/mixed.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/test/resources/mixed.xsd (original)
+++ incubator/tuscany/java/sdo/impl/src/test/resources/mixed.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
 <xsd:schema 
   targetNamespace="http://www.example.com/mixed"

Modified: incubator/tuscany/java/sdo/impl/src/test/resources/names.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/test/resources/names.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/test/resources/names.xsd (original)
+++ incubator/tuscany/java/sdo/impl/src/test/resources/names.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
 <xsd:schema 
   targetNamespace="http://www.example.com/names"

Modified: incubator/tuscany/java/sdo/impl/src/test/resources/open.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/test/resources/open.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/test/resources/open.xsd (original)
+++ incubator/tuscany/java/sdo/impl/src/test/resources/open.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
 <xsd:schema 
   xmlns:simple="http://www.example.com/open" 

Modified: incubator/tuscany/java/sdo/impl/src/test/resources/sdoannotations.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/test/resources/sdoannotations.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/test/resources/sdoannotations.xsd (original)
+++ incubator/tuscany/java/sdo/impl/src/test/resources/sdoannotations.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
 <xsd:schema 
   targetNamespace="http://www.example.com/sdoannotations"

Modified: incubator/tuscany/java/sdo/impl/src/test/resources/sdotypes.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/test/resources/sdotypes.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/test/resources/sdotypes.xsd (original)
+++ incubator/tuscany/java/sdo/impl/src/test/resources/sdotypes.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
 <xsd:schema 
   targetNamespace="http://www.example.com/sdotypes"

Modified: incubator/tuscany/java/sdo/impl/src/test/resources/simple.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/test/resources/simple.xsd?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/test/resources/simple.xsd (original)
+++ incubator/tuscany/java/sdo/impl/src/test/resources/simple.xsd Wed Oct 18 05:25:18 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!--
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- * 
- *   http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.    
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+    
+    http://www.apache.org/licenses/LICENSE-2.0
+    
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.    
  -->
 <xsd:schema 
   targetNamespace="http://www.example.com/simple"

Modified: incubator/tuscany/java/sdo/pom.xml
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/pom.xml?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/pom.xml (original)
+++ incubator/tuscany/java/sdo/pom.xml Wed Oct 18 05:25:18 2006
@@ -71,8 +71,8 @@
         <module>impl</module>
         <module>tools</module>
         <module>plugin</module>
-        <module>sample</module>
-        <module>distribution</module>
+        <!-- <module>sample</module>   -->
+        <!-- <module>distribution</module>  -->
     </modules>
 
     <build>
@@ -96,7 +96,57 @@
                     </includes>
                 </configuration>
             </plugin>
+            
+            <plugin>
+                <groupId>org.apache.maven.plugins</groupId>
+                <artifactId>maven-dependency-plugin</artifactId>
+                <!-- <version>${dependency.plugin.version}</version>  -->
+                <executions>
+                    <execution>
+                        <id>unpack-javadoc</id>
+                        <phase>package</phase>
+                        <goals>
+                            <goal>unpack</goal>
+                        </goals>
+                        <configuration>
+                            <artifactItems>
+                                <artifactItem>
+                                    <groupId>commonj</groupId>
+                                    <artifactId>sdo-api-r${specVersion}</artifactId>
+                                    <classifier>javadoc</classifier>
+                                    <version>${pom.version}</version>
+                                    <outputDirectory>${project.build.directory}/javadoc/api</outputDirectory>
+                                </artifactItem>
+                            </artifactItems>
+                        </configuration>
+                    </execution>
+                </executions>
+            </plugin>               
+            <plugin>
+                <groupId>org.apache.maven.plugins</groupId>
+                <artifactId>maven-assembly-plugin</artifactId>
+                <version>2.2-SNAPSHOT</version>
+                <configuration>
+                    <descriptors>
+                        <descriptor>sdo.xml</descriptor>
+                    </descriptors>
+                </configuration>
+            </plugin>
         </plugins>
+
+        <pluginManagement>
+            <plugins>
+            <plugin>
+                <groupId>org.apache.maven.plugins</groupId>
+                <artifactId>maven-javadoc-plugin</artifactId>
+                <configuration>
+                    <aggregate>true</aggregate>
+                    <version>2.0</version>
+                </configuration>
+            </plugin>
+        </plugins>
+        </pluginManagement>
+
     </build>
 
     <dependencyManagement>

Added: incubator/tuscany/java/sdo/sample/LICENSE.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/sample/LICENSE.txt?view=auto&rev=465232
==============================================================================
--- incubator/tuscany/java/sdo/sample/LICENSE.txt (added)
+++ incubator/tuscany/java/sdo/sample/LICENSE.txt Wed Oct 18 05:25:18 2006
@@ -0,0 +1,236 @@
+
+                                 Apache License
+                           Version 2.0, January 2004
+                        http://www.apache.org/licenses/
+
+   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION
+
+   1. Definitions.
+
+      "License" shall mean the terms and conditions for use, reproduction,
+      and distribution as defined by Sections 1 through 9 of this document.
+
+      "Licensor" shall mean the copyright owner or entity authorized by
+      the copyright owner that is granting the License.
+
+      "Legal Entity" shall mean the union of the acting entity and all
+      other entities that control, are controlled by, or are under common
+      control with that entity. For the purposes of this definition,
+      "control" means (i) the power, direct or indirect, to cause the
+      direction or management of such entity, whether by contract or
+      otherwise, or (ii) ownership of fifty percent (50%) or more of the
+      outstanding shares, or (iii) beneficial ownership of such entity.
+
+      "You" (or "Your") shall mean an individual or Legal Entity
+      exercising permissions granted by this License.
+
+      "Source" form shall mean the preferred form for making modifications,
+      including but not limited to software source code, documentation
+      source, and configuration files.
+
+      "Object" form shall mean any form resulting from mechanical
+      transformation or translation of a Source form, including but
+      not limited to compiled object code, generated documentation,
+      and conversions to other media types.
+
+      "Work" shall mean the work of authorship, whether in Source or
+      Object form, made available under the License, as indicated by a
+      copyright notice that is included in or attached to the work
+      (an example is provided in the Appendix below).
+
+      "Derivative Works" shall mean any work, whether in Source or Object
+      form, that is based on (or derived from) the Work and for which the
+      editorial revisions, annotations, elaborations, or other modifications
+      represent, as a whole, an original work of authorship. For the purposes
+      of this License, Derivative Works shall not include works that remain
+      separable from, or merely link (or bind by name) to the interfaces of,
+      the Work and Derivative Works thereof.
+
+      "Contribution" shall mean any work of authorship, including
+      the original version of the Work and any modifications or additions
+      to that Work or Derivative Works thereof, that is intentionally
+      submitted to Licensor for inclusion in the Work by the copyright owner
+      or by an individual or Legal Entity authorized to submit on behalf of
+      the copyright owner. For the purposes of this definition, "submitted"
+      means any form of electronic, verbal, or written communication sent
+      to the Licensor or its representatives, including but not limited to
+      communication on electronic mailing lists, source code control systems,
+      and issue tracking systems that are managed by, or on behalf of, the
+      Licensor for the purpose of discussing and improving the Work, but
+      excluding communication that is conspicuously marked or otherwise
+      designated in writing by the copyright owner as "Not a Contribution."
+
+      "Contributor" shall mean Licensor and any individual or Legal Entity
+      on behalf of whom a Contribution has been received by Licensor and
+      subsequently incorporated within the Work.
+
+   2. Grant of Copyright License. Subject to the terms and conditions of
+      this License, each Contributor hereby grants to You a perpetual,
+      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
+      copyright license to reproduce, prepare Derivative Works of,
+      publicly display, publicly perform, sublicense, and distribute the
+      Work and such Derivative Works in Source or Object form.
+
+   3. Grant of Patent License. Subject to the terms and conditions of
+      this License, each Contributor hereby grants to You a perpetual,
+      worldwide, non-exclusive, no-charge, royalty-free, irrevocable
+      (except as stated in this section) patent license to make, have made,
+      use, offer to sell, sell, import, and otherwise transfer the Work,
+      where such license applies only to those patent claims licensable
+      by such Contributor that are necessarily infringed by their
+      Contribution(s) alone or by combination of their Contribution(s)
+      with the Work to which such Contribution(s) was submitted. If You
+      institute patent litigation against any entity (including a
+      cross-claim or counterclaim in a lawsuit) alleging that the Work
+      or a Contribution incorporated within the Work constitutes direct
+      or contributory patent infringement, then any patent licenses
+      granted to You under this License for that Work shall terminate
+      as of the date such litigation is filed.
+
+   4. Redistribution. You may reproduce and distribute copies of the
+      Work or Derivative Works thereof in any medium, with or without
+      modifications, and in Source or Object form, provided that You
+      meet the following conditions:
+
+      (a) You must give any other recipients of the Work or
+          Derivative Works a copy of this License; and
+
+      (b) You must cause any modified files to carry prominent notices
+          stating that You changed the files; and
+
+      (c) You must retain, in the Source form of any Derivative Works
+          that You distribute, all copyright, patent, trademark, and
+          attribution notices from the Source form of the Work,
+          excluding those notices that do not pertain to any part of
+          the Derivative Works; and
+
+      (d) If the Work includes a "NOTICE" text file as part of its
+          distribution, then any Derivative Works that You distribute must
+          include a readable copy of the attribution notices contained
+          within such NOTICE file, excluding those notices that do not
+          pertain to any part of the Derivative Works, in at least one
+          of the following places: within a NOTICE text file distributed
+          as part of the Derivative Works; within the Source form or
+          documentation, if provided along with the Derivative Works; or,
+          within a display generated by the Derivative Works, if and
+          wherever such third-party notices normally appear. The contents
+          of the NOTICE file are for informational purposes only and
+          do not modify the License. You may add Your own attribution
+          notices within Derivative Works that You distribute, alongside
+          or as an addendum to the NOTICE text from the Work, provided
+          that such additional attribution notices cannot be construed
+          as modifying the License.
+
+      You may add Your own copyright statement to Your modifications and
+      may provide additional or different license terms and conditions
+      for use, reproduction, or distribution of Your modifications, or
+      for any such Derivative Works as a whole, provided Your use,
+      reproduction, and distribution of the Work otherwise complies with
+      the conditions stated in this License.
+
+   5. Submission of Contributions. Unless You explicitly state otherwise,
+      any Contribution intentionally submitted for inclusion in the Work
+      by You to the Licensor shall be under the terms and conditions of
+      this License, without any additional terms or conditions.
+      Notwithstanding the above, nothing herein shall supersede or modify
+      the terms of any separate license agreement you may have executed
+      with Licensor regarding such Contributions.
+
+   6. Trademarks. This License does not grant permission to use the trade
+      names, trademarks, service marks, or product names of the Licensor,
+      except as required for reasonable and customary use in describing the
+      origin of the Work and reproducing the content of the NOTICE file.
+
+   7. Disclaimer of Warranty. Unless required by applicable law or
+      agreed to in writing, Licensor provides the Work (and each
+      Contributor provides its Contributions) on an "AS IS" BASIS,
+      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
+      implied, including, without limitation, any warranties or conditions
+      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
+      PARTICULAR PURPOSE. You are solely responsible for determining the
+      appropriateness of using or redistributing the Work and assume any
+      risks associated with Your exercise of permissions under this License.
+
+   8. Limitation of Liability. In no event and under no legal theory,
+      whether in tort (including negligence), contract, or otherwise,
+      unless required by applicable law (such as deliberate and grossly
+      negligent acts) or agreed to in writing, shall any Contributor be
+      liable to You for damages, including any direct, indirect, special,
+      incidental, or consequential damages of any character arising as a
+      result of this License or out of the use or inability to use the
+      Work (including but not limited to damages for loss of goodwill,
+      work stoppage, computer failure or malfunction, or any and all
+      other commercial damages or losses), even if such Contributor
+      has been advised of the possibility of such damages.
+
+   9. Accepting Warranty or Additional Liability. While redistributing
+      the Work or Derivative Works thereof, You may choose to offer,
+      and charge a fee for, acceptance of support, warranty, indemnity,
+      or other liability obligations and/or rights consistent with this
+      License. However, in accepting such obligations, You may act only
+      on Your own behalf and on Your sole responsibility, not on behalf
+      of any other Contributor, and only if You agree to indemnify,
+      defend, and hold each Contributor harmless for any liability
+      incurred by, or claims asserted against, such Contributor by reason
+      of your accepting any such warranty or additional liability.
+
+   END OF TERMS AND CONDITIONS
+
+   APPENDIX: How to apply the Apache License to your work.
+
+      To apply the Apache License to your work, attach the following
+      boilerplate notice, with the fields enclosed by brackets "[]"
+      replaced with your own identifying information. (Don't include
+      the brackets!)  The text should be enclosed in the appropriate
+      comment syntax for the file format. We also recommend that a
+      file or class name and description of purpose be included on the
+      same "printed page" as the copyright notice for easier
+      identification within third-party archives.
+
+   Copyright [yyyy] [name of copyright owner]
+
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+
+
+===============================================================================================================
+
+
+License for the Service Data Objects JavaDoc and Interface Definition files.
+
+Permission to copy, make derivative works of, and distribute the Service Data Objects 
+JavaDoc and Interface Definition Files files in any medium without fee or royalty as part 
+of a compliant implementation of the Service Data Objects Specification is hereby granted.  
+The Service Data Objects Specification may be found at any of the following locations:
+
+http://dev2dev.bea.com/technologies/commonj/index.jsp
+http://www.ibm.com/developerworks/library/specification/ws-sdo/
+http://oracle.com/technology/webservices/sca
+https://www.sdn.sap.com/
+http://www.xcalia/xdn/specs/sdo
+
+THE SERVICE DATA OBJECTS SPECIFICATION AND THE JAVADOC AND INTERFACE DEFINITION FILES 
+ARE PROVIDED "AS IS," AND THE AUTHORS MAKE NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED, REGARDING THIS 
+SPECIFICATION OR THE JAVADOC AND INTERFACE DEFINITION FILES AND THE IMPLEMENTATION OF THEIR CONTENTS, 
+INCLUDING, BUT NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, 
+NON-INFRINGEMENT OR TITLE.  THE AUTHORS WILL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, 
+INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF OR RELATING TO ANY USE OR DISTRIBUTION OF THE 
+SERVICE DATA OBJECTS SPECIFICATION OR THE JAVADOC OR INTERFACE DEFINTION FILES.
+
+The name and trademarks of the Authors may NOT be used in any manner, including advertising or 
+publicity pertaining to the Service Component Architecture Specification or its contents without specific, 
+written prior permission. Title to copyright in the Service Data Objects Specification and the 
+JavaDoc and Interface Definition Files will at all times remain with the Authors.
+
+No other rights are granted by implication, estoppel or otherwise.
+
+

Added: incubator/tuscany/java/sdo/sample/NOTICE.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/sample/NOTICE.txt?view=auto&rev=465232
==============================================================================
--- incubator/tuscany/java/sdo/sample/NOTICE.txt (added)
+++ incubator/tuscany/java/sdo/sample/NOTICE.txt Wed Oct 18 05:25:18 2006
@@ -0,0 +1,34 @@
+Apache Tuscany SDO for Java
+Copyright 2006 The Apache Software Foundation
+
+This product includes software developed at
+The Apache Software Foundation (http://www.apache.org/).
+
+Apache Tuscany is an effort undergoing incubation at The Apache Software Foundation (ASF),
+sponsored by the Apache Web Services PMC. Incubation is required of all newly accepted
+projects until a further review indicates that the infrastructure, communications,
+and decision making process have stabilized in a manner consistent with other successful
+ASF projects. While incubation status is not necessarily a reflection of the completeness
+or stability of the code, it does indicate that the project has yet to be fully endorsed
+by the ASF.
+
+Unless otherwise indicated, all distribution made available by the Apache Software Foundation
+is provided to you under the terms and conditions of the Apache License Version 2.0 ("AL").
+A copy of the AL is provided with this distribution as the LICENSE.txt file present in the
+root directory, and is also available at http://www.apache.org/licenses/.
+
+The terms and conditions governing the distribution may refer to the AL or other license
+agreements, notices or terms and conditions. Some of these other license agreements may
+include (but are not limited to):
+
+  . Eclipse Public License Version 1.0 (available at http://www.eclipse.org/legal/epl-v10.html)
+  . Common Public License Version 1.0 (available at http://www.eclipse.org/legal/cpl-v10.html)
+
+It is your obligation to read and accept all such terms and conditions prior to use of the
+distribution. If term or condition is provided, please contact the Apache Software Foundation
+to determine what terms and conditions govern that particular distribution.
+
+This product also includes software developed by the Open Service Oriented Architecture organisation
+(http://osoa.org). The license for this software may be found in the LICENSE.txt file contained in this
+distribution.
+

Added: incubator/tuscany/java/sdo/sample/README.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/sample/README.txt?view=auto&rev=465232
==============================================================================
--- incubator/tuscany/java/sdo/sample/README.txt (added)
+++ incubator/tuscany/java/sdo/sample/README.txt Wed Oct 18 05:25:18 2006
@@ -0,0 +1,20 @@
+Tuscany SDO Java M2 Sample Program Distribution
+===============================================
+
+This is a distribution of the sample programs for the Tuscany SDO Java implementation.
+
+Building the SDO Java Samples Project from this source distribution 
+-------------------------------------------------------------------
+
+Note: If you have already built the SDO for Java Implementation source distribution
+then these sample programs are included in that distribution and are built as part
+of that process.  This distribution archive is provided for building against a
+binary distribution of SDO for Java. 
+
+Ensure that all the jar files found in the SDO for Java binary distribution's
+lib directory are on your java classpath, and use your java 1.4.2 (or greater) compiler to
+compile the classes in this distribution in your own favourite development environment.
+
+Look at the site/apidocs/index.html to understand how to run these programs.
+
+

Added: incubator/tuscany/java/sdo/sample/STATUS.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/sample/STATUS.txt?view=auto&rev=465232
==============================================================================
--- incubator/tuscany/java/sdo/sample/STATUS.txt (added)
+++ incubator/tuscany/java/sdo/sample/STATUS.txt Wed Oct 18 05:25:18 2006
@@ -0,0 +1,73 @@
+Apache Tuscany Status
+
+Tuscany provides multiple language implementations of the Service Component Architecture (SCA) specifications and related technologies such as SDO.
+
+PROJECT STATUS
+==============
+
+  Tuscany is being incubated at the request of the Apache Web Services PMC.
+  For information on incubation please visit the project page at
+  http://incubator.apache.org/projects/tuscany.html
+
+PENDING ISSUES
+==============
+XXXX-XX-XX CCLA received for IBM's contribution of a C++ implementation
+XXXX-XX-XX CCLA received for BEA and IBM joint contribution of a Java implementation
+
+RESOLVED ISSUES SINCE LAST STATUS
+=================================
+None
+
+OTHER NEWS
+==========
+
+2006-09-29 Vote to add Ignacio Silva-Lepe as a new committer
+2006-09-18 Vote to add Venkata Krishnan as a new committer
+2006-08-10 Vote to add Andrew Borley as a new committer
+2006-08-07 Vote to add Meeraj Kunnumpurath as a new committer
+2006-08-07 Vote to add Kelvin Goodson as a new committer
+2006-08-06 Vote to add Brent Daniel as a new committer
+2006-08-04 Vote to add Raymond Feng as a new committer
+2006-08-01 C++ Milestone 1 release
+2006-06-07 Java Milestone 1 release
+2006-05-02 Vote to add Dan Kulp as a new committer
+
+2006-01-05 Contribution of Java implementation by BEA and IBM committed
+2006-01-05 Contribution of C+ implementation by IBM committed
+
+RELEASE STATUS
+==============
+None
+
+REFERENCES
+==========
+Status file     http://svn.apache.org/repos/asf/incubator/tuscany/STATUS
+User List       tuscany-user@ws.apache.org
+Developer List  tuscany-dev@ws.apache.org
+Commits List    tuscany-commits@ws.apache.org
+Source Code     http://svn.apache.org/repos/asf/incubator/tuscany/
+Issue Tracking  http://issues.apache.org/jira/browse/TUSCANY
+
+Committers
+    ajborley        Andrew Borley
+    antelder        Ant Elder
+    bdaniel         Brent Daniel
+    dkulp           Dan Kulp
+    dims            Davanum Srinivas
+    edslattery      Ed Slattery
+    ekoneil         Eddie O'Neil
+    frankb          Frank Budinsky
+    geirm           Geir Magnusson Jr
+    isilval         Ignacio Silva-Lepe
+    jsdelfino       Jean-Sebastien Delfino
+    jboynes         Jeremy Boynes
+    jmarino         Jim Marino
+    kelvingoodson   Kelvin Goodson
+    kentam          Ken Tam
+    kwilliams       Kevin Williams
+    edwardsmj       Mike Edwards
+    meerajk         Meeraj Kunnumpurath
+    rfeng           Raymond Feng
+    robbinspg       Pete Robbins
+    rineholt        Rick Rineholt
+    svkrish         Venkata Krishnan

Modified: incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/ExecuteSamples.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/ExecuteSamples.java?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/ExecuteSamples.java (original)
+++ incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/ExecuteSamples.java Wed Oct 18 05:25:18 2006
@@ -172,7 +172,7 @@
                     .println("--------------------------------------------------------------------------------------------------------------------------");
 
             System.out
-                    .println("The next two samples are based upon Fuhwei Lo's paper http://www-128.ibm.com/developerworks/webservices/library/ws-sdoxmlschema/");
+                    .println("The next two samples are based upon Fuhwei Lwo's paper http://www-128.ibm.com/developerworks/webservices/library/ws-sdoxmlschema/");
             System.out.println(">>>Press Enter to continue");
             in.readLine();
             CreatePurchaseOrder.main(args);

Modified: incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/otherSources/CreatePurchaseOrder.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/otherSources/CreatePurchaseOrder.java?view=diff&rev=465232&r1=465231&r2=465232
==============================================================================
--- incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/otherSources/CreatePurchaseOrder.java (original)
+++ incubator/tuscany/java/sdo/sample/src/main/java/org/apache/tuscany/samples/sdo/otherSources/CreatePurchaseOrder.java Wed Oct 18 05:25:18 2006
@@ -37,7 +37,7 @@
  * {@link org.apache.tuscany.samples.sdo.SdoSampleConstants#PO_XSD_RESOURCE} to
  * define types then generates a purchase order DataObject and persists to
  * {@link org.apache.tuscany.samples.sdo.SdoSampleConstants#PO_XML_GENERATED}. This
  * sample was used to generate valid XML for Fuhwei Lo's paper <A
  * HREF="http://www-128.ibm.com/developerworks/webservices/library/ws-sdoxmlschema/"
  * title="Me" onClick="checkLinks(this)">Create and read an XML document based on XML
  * Schema</A>
@@ -113,7 +113,7 @@
             System.out.println("***************************************");
             System.out.println("SDO Sample CreatePurchaseOrder");
             System.out.println("***************************************");
-            System.out.println("This sample is based upon Fuhwei Lo's paper "
+            System.out.println("This sample is based upon Fuhwei Lwo's paper "
                     + "http://www-128.ibm.com/developerworks/webservices/library/ws-sdoxmlschema/"
                     + " and demonstrates creating a purchaseOrder DataObject from an "
                     + " existing XSD and then persisting to disk. Uses previously defined model");



---------------------------------------------------------------------
@@ -37,7 +37,7 @@
  * define types then generates a purchase order DataObject and persists to
  * {@link org.apache.tuscany.samples.sdo.SdoSampleConstants#PO_XML_GENERATED}. This
- * sample was used to generate valid XML for Fuhwei Lo's paper <A
+ * sample was used to generate valid XML for Fuhwei Lwo's paper <A
  * HREF="http://www-128.ibm.com/developerworks/webservices/library/ws-sdoxmlschema/"
  * title="Me" onClick="checkLinks(this)">Create and read an XML document based on XML
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org